%% BMELAB_STUDENT_DEMO: demo script to run an demo experiment with BMELAB.m
%
% This file runs a single experiment with BMELAB.m. It uses a filtered
% random signal as disturbance. For more details on the experiment itself,
% see BMELAB.m.
%
% See also bmelab

clear; clc
disp('----------------------------------------------------------------')
disp('------------------        BME-lab demo      --------------------')
disp('----------------------------------------------------------------')
disp(' ')
%% Get user input

% Direction
distDir = input('Disturbance direction horizontal / vertical / both ([h]/v/b): ', 's');
if isempty(distDir)
    distDir = 'h';
end
switch distDir
    case 'v'
        enableX = 0;
        enableY = 1;
    case 'h'
        enableX = 1;
        enableY = 0;
    case 'b'
        enableX = 1;
        enableY = 1;
    otherwise
        warning('bmelab:illegalInput', ['''', distDir, ''' is not a valid option. Defaulting to ''h'''])
        distDir = 'h';
        enableX = 1;
        enableY = 0;
end

% Task
distTask = input('Task instruction: pursuit or compensatory ([p]/c): ', 's');
if isempty(distTask)
    distTask = 'p';
end
switch distTask
    case 'c'
        task = 'compensate';
    case 'p'
        task = 'pursuit';
    otherwise
        warning('bmelab:illegalInput', ['''', distTask, ''' is not a valid option. Defaulting to ''c'''])
        task = 'compensate';
end

%% Settings
T       = 35;           % Measurement time per trial [s]
dt      = 0.025;        % Sample time [s] (40Hz)
sys     = tf(1,[1 1]);  % Transfer function of controlled system


%% Init data variables
N       = T / dt;

%% Create disturbance signals

% Random signal
w_inX   = randn(N,1);
w_inY   = randn(N,1);
w_inX = w_inX - mean(w_inX);
w_inY = w_inY - mean(w_inY);

% Create filter
fcut = 0.5;
[B,A] = butter(2, 2* fcut * dt);

% Apply low pass filter
w_inX = filtfilt(B,A,w_inX);
w_inY = filtfilt(B,A,w_inY);

% Scale time signal to max. abs. amplitude of 0.5
w_inX = enableX * 0.5 * w_inX / max(abs(w_inX));
w_inY = enableY * 0.5 * w_inY / max(abs(w_inY));

%% Run experiment
data = bmelab(w_inX, w_inY, dt, sys, task);

%% Plot data
figure

subplot(2,2,1)
plot(data.t, [data.wx, data.wy])
title('Disturbance')
legend({'hor.', 'ver.'})
xlabel('time [s]')
ylabel('w [-]')

subplot(2,2,2)
plot(data.t, [data.ex, data.ey])
title('Error')
xlabel('time [s]')
ylabel('e [-]')

subplot(2,2,3)
plot(data.t, [data.xx, data.xy])
title('Position')
xlabel('time [s]')
ylabel('x [-]')

subplot(2,2,4)
plot(data.t, [data.ux, data.uy])
title('Human input')
xlabel('time [s]')
ylabel('u [-]')

